From cd80d8c61c6ed946a1ff1b7998bb6560f2976744 Mon Sep 17 00:00:00 2001
From: Juan RP <xtraeme@gmail.com>
Date: Mon, 3 Jun 2019 12:15:47 +0200
Subject: [PATCH] efl: update to 1.22.2.

- Added new build options: elogind, drm, gstreamer and vlc.
- The same options that were available before are kept.
- Tested on x86_64.
---
 common/options.description |  2 ++
 srcpkgs/efl/template       | 71 +++++++++++++++++---------------------
 2 files changed, 33 insertions(+), 40 deletions(-)

diff --git a/common/options.description b/common/options.description
index f7f206c5bbf..5d34d2f4068 100644
--- a/common/options.description
+++ b/common/options.description
@@ -94,3 +94,5 @@ desc_option_xml="Enable support for XML"
 desc_option_xscreensaver="Enable support for libXScrnSaver to determine idle time"
 desc_option_zeitgeist="Enable support for ZeitGeist"
 desc_option_zstd="Enable support for ZSTD compression format"
+desc_option_elogind="Enable support for elogind"
+desc_option_drm="Enable support for DRM"
diff --git a/srcpkgs/efl/template b/srcpkgs/efl/template
index 761f25320ca..6f0fa1a28f4 100644
--- a/srcpkgs/efl/template
+++ b/srcpkgs/efl/template
@@ -1,17 +1,34 @@
 # Template file for 'efl'
 pkgname=efl
-version=1.22.1
+version=1.22.2
 revision=1
 build_style=gnu-configure
-configure_args="CXX= --enable-multisense --enable-image-loader-webp --enable-liblz4
- --disable-systemd $(vopt_enable framebuffer fb) $(vopt_enable pulseaudio)
- $(vopt_enable harfbuzz)"
+configure_args="CXX= --disable-systemd --enable-liblz4
+ --enable-multisense --enable-image-loader-webp
+ $(vopt_enable gstreamer gstreamer1) $(vopt_enable vlc libvlc)
+ $(vopt_enable framebuffer fb) $(vopt_enable pulseaudio)
+ $(vopt_enable harfbuzz) $(vopt_if opengl '--with-opengl=full')
+ $(vopt_if gles2 '--enable-egl --with-opengl=es')
+ $(vopt_if drm '--enable-drm --enable-elput')
+ $(vopt_if wayland '--enable-wayland --enable-wayland-ivi-shell')
+ $(vopt_if x11 '--enable-xinput22 --with-x11=xlib --enable-xpresent')
+ $(vopt_if elogind '--enable-elput --enable-elogind')"
 hostmakedepends="pkg-config"
-makedepends="liblz4-devel libressl-devel glib-devel libjpeg-turbo-devel fontconfig-devel
+makedepends="
+ liblz4-devel libressl-devel glib-devel libjpeg-turbo-devel fontconfig-devel
  fribidi-devel giflib-devel libpng-devel tiff-devel libwebp-devel
- gst-plugins-base1-devel avahi-libs-devel eudev-libudev-devel bullet-devel
+ avahi-libs-devel eudev-libudev-devel bullet-devel
  alsa-lib-devel libsndfile-devel libmount-devel LuaJIT-devel poppler-cpp-devel
- librsvg-devel vlc-devel libspectre-devel libraw-devel
+ librsvg-devel libspectre-devel libraw-devel
+ $(vopt_if gstreamer gst-plugins-base1-devel) $(vopt_if opengl MesaLib-devel)
+ $(vopt_if vlc vlc-devel) $(vopt_if elogind 'elogind-devel libinput-devel libxkbcommon-devel')
+ $(vopt_if gles2 'libinput-devel libxkbcommon-devel MesaLib-devel')
+ $(vopt_if wayland 'libxkbcommon-devel wayland-protocols wayland-devel libinput-devel')
+ $(vopt_if x11 'libXcomposite-devel libXcursor-devel libXp-devel
+	libXrandr-devel libXScrnSaver-devel libXdamage-devel
+	libXrender-devel libXi-devel libXinerama-devel libXpresent-devel
+	xcb-util-devel xcb-util-keysyms-devel xcb-util-image-devel
+	xcb-util-renderutil-devel xcb-util-wm-devel xorgproto')
  $(vopt_if harfbuzz harfbuzz-devel) $(vopt_if pulseaudio pulseaudio-devel)"
 short_desc="Enlightenment Foundation Libraries"
 maintainer="Juan RP <xtraeme@voidlinux.org>"
@@ -19,7 +36,7 @@ license="LGPL-2.1-only"
 homepage="http://enlightenment.org"
 changelog="https://raw.githubusercontent.com/Enlightenment/efl/master/NEWS"
 distfiles="http://download.enlightenment.org/rel/libs/efl/efl-${version}.tar.xz"
-checksum=20d3e5e945d54ae46ec916c7341b5dec24f904b6c0123b4d3ecb8cd8d596ae12
+checksum=1699891f825911622de0aa77fe1140eff7335aba619d2352485e54dcff6b1cd0
 
 if [ "$CROSS_BUILD" ]; then
 	hostmakedepends+="  automake gettext-devel libtool efl-devel"
@@ -37,13 +54,15 @@ if [ "$CROSS_BUILD" ]; then
 fi
 
 # Package build options
-build_options="framebuffer gles2 harfbuzz opengl pulseaudio wayland x11"
-# Enable harfbuzz, pulseaudio and x11 by default.
-build_options_default="harfbuzz pulseaudio x11"
+build_options="elogind drm framebuffer gles2 gstreamer harfbuzz opengl pulseaudio vlc wayland x11"
+desc_option_gst="Enable support for video previews via gstreamer"
+desc_option_vlc="Enable support for video previews via VLC"
+# Enable gstreamer, harfbuzz, pulseaudio and x11 by default.
+build_options_default="gstreamer harfbuzz pulseaudio x11"
 
 case "$XBPS_TARGET_MACHINE" in
 	i686*|x86_64*|ppc64*)
-		# Enable gles2 by default on x86.
+		# Enable opengl by default on x86/ppc64.
 		build_options_default+=" opengl"
 		;;
 	armv6l*)
@@ -59,34 +78,6 @@ case "$XBPS_TARGET_MACHINE" in
 		;;
 esac
 
-if [ "$build_option_opengl" ]; then
-	configure_args+=" --with-opengl=full"
-	makedepends+=" MesaLib-devel"
-elif [ "$build_option_gles2" ]; then
-	configure_args+=" --with-opengl=es"
-	makedepends+=" MesaLib-devel"
-else
-	configure_args+=" --with-opengl=none"
-fi
-
-if [ "$build_option_wayland" ]; then
-	configure_args+=" --enable-egl --enable-wayland --enable-wayland-ivi-shell"
-	makedepends+=" libxkbcommon-devel wayland-devel libinput-devel"
-else
-	configure_args+=" --disable-egl --disable-wayland"
-fi
-
-if [ "$build_option_x11" ]; then
-	configure_args+=" --with-x --enable-xinput22 --with-x11=xlib"
-	makedepends+=" libXcomposite-devel libXcursor-devel libXp-devel"
-	makedepends+=" libXrandr-devel libXScrnSaver-devel"
-	makedepends+=" libXdamage-devel libXrender-devel libXi-devel libXinerama-devel"
-	makedepends+=" xcb-util-devel xcb-util-keysyms-devel xcb-util-image-devel"
-	makedepends+=" xcb-util-renderutil-devel xcb-util-wm-devel xorgproto"
-else
-	configure_args+=" --without-x --with-x11=none"
-fi
-
 efl-devel_package() {
 	short_desc+=" - development files"
 	depends="${makedepends} efl>=${version}_${revision}"
